@@ -1,11 +1,12 @@
+from typing import Any
 from . import defaults
 
-__title__ = 'tld.conf'
 __author__ = 'Artur Barseghyan'
-__copyright__ = '2013-2018 Artur Barseghyan'
-__license__ = 'GPL 2.0/LGPL 2.1'
+__copyright__ = '2013-2019 Artur Barseghyan'
+__license__ = 'MPL-1.1 OR GPL-2.0-only OR LGPL-2.1-or-later'
 __all__ = (
     'get_setting',
+    'reset_settings',
     'set_setting',
     'settings',
 )
@@ -16,8 +17,9 @@ class Settings(object):
 
     def __init__(self):
         self._settings = {}
+        self._settings_get = self._settings.get
 
-    def set(self, name, value):
+    def set(self, name: str, value: Any) -> None:
         """
         Override default settings.
 
@@ -26,7 +28,7 @@ class Settings(object):
         """
         self._settings[name] = value
 
-    def get(self, name, default=None):
+    def get(self, name: str, default: Any = None) -> Any:
         """
         Gets a variable from local settings.
 
@@ -35,15 +37,22 @@ class Settings(object):
         :return mixed:
         """
         if name in self._settings:
-            return self._settings.get(name, default)
+            return self._settings_get(name, default)
         elif hasattr(defaults, name):
             return getattr(defaults, name, default)
 
         return default
 
+    def reset(self) -> None:
+        """Reset settings."""
+        for name in defaults.__all__:
+            self.set(name, getattr(defaults, name))
+
 
 settings = Settings()
 
 get_setting = settings.get
 
 set_setting = settings.set
+
+reset_settings = settings.reset
